@@ -53,6 +53,41 @@ g_convert_error_quark()
 #error libiconv not in use but included iconv.h is from libiconv
 #endif
 
+static gboolean
+try_conversion (const char *to_codeset,
+		const char *from_codeset,
+		iconv_t    *cd)
+{
+  *cd = iconv_open (to_codeset, from_codeset);
+
+  if (*cd == (iconv_t)-1 && errno == EINVAL)
+    return FALSE;
+  else
+    return TRUE;
+}
+
+static gboolean
+try_to_aliases (const char **to_aliases,
+		const char  *from_codeset,
+		iconv_t     *cd)
+{
+  if (to_aliases)
+    {
+      const char **p = to_aliases;
+      while (*p)
+	{
+	  if (try_conversion (*p, from_codeset, cd))
+	    return TRUE;
+
+	  p++;
+	}
+    }
+
+  return FALSE;
+}
+
+extern const char **_g_charset_get_aliases (const char *canonical_name);
+
 /**
  * g_iconv_open:
  * @to_codeset: destination codeset
@@ -71,8 +106,32 @@ GIConv
 g_iconv_open (const gchar  *to_codeset,
 	      const gchar  *from_codeset)
 {
-  iconv_t cd = iconv_open (to_codeset, from_codeset);
+  iconv_t cd;
   
+  if (!try_conversion (to_codeset, from_codeset, &cd))
+    {
+      const char **to_aliases = _g_charset_get_aliases (to_codeset);
+      const char **from_aliases = _g_charset_get_aliases (from_codeset);
+
+      if (from_aliases)
+	{
+	  const char **p = from_aliases;
+	  while (*p)
+	    {
+	      if (try_conversion (to_codeset, *p, &cd))
+		return (GIConv)cd;
+
+	      if (try_to_aliases (to_aliases, *p, &cd))
+		return (GIConv)cd;
+
+	      p++;
+	    }
+	}
+
+      if (try_to_aliases (to_aliases, from_codeset, &cd))
+	return (GIConv)cd;
+    }
+
   return (GIConv)cd;
 }
 
@@ -140,11 +199,11 @@ open_converter (const gchar *to_codeset,
       /* Something went wrong.  */
       if (errno == EINVAL)
         g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_NO_CONVERSION,
-                     _("Conversion from character set `%s' to `%s' is not supported"),
+                     _("Conversion from character set '%s' to '%s' is not supported"),
                      from_codeset, to_codeset);
       else
         g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_FAILED,
-                     _("Could not open converter from `%s' to `%s': %s"),
+                     _("Could not open converter from '%s' to '%s': %s"),
                      from_codeset, to_codeset, strerror (errno));
     }
 
@@ -160,22 +219,22 @@ open_converter (const gchar *to_codeset,
  * @from_codeset:  character set of @str.
  * @bytes_read:    location to store the number of bytes in the
  *                 input string that were successfully converted, or %NULL.
- *                 Even if the conversion was succesful, this may be 
- *                 less than len if there were partial characters
+ *                 Even if the conversion was successful, this may be 
+ *                 less than @len if there were partial characters
  *                 at the end of the input. If the error
- *                 G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
- *                 stored will the byte fofset after the last valid
+ *                 #G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
+ *                 stored will the byte offset after the last valid
  *                 input sequence.
- * @bytes_written: the stored in the output buffer (not including the
- *                 terminating nul.
+ * @bytes_written: the number of bytes stored in the output buffer (not 
+ *                 including the terminating NULL).
  * @error:         location to store the error occuring, or %NULL to ignore
  *                 errors. Any of the errors in #GConvertError may occur.
  *
  * Convert a string from one character set to another.
  *
  * Return value: If the conversion was successful, a newly allocated
- *               NUL-terminated string, which must be freed with
- *               g_free. Otherwise %NULL and @error will be set.
+ *               nul-terminated string, which must be freed with
+ *               g_free(). Otherwise %NULL and @error will be set.
  **/
 gchar*
 g_convert (const gchar *str,
@@ -223,21 +282,21 @@ g_convert (const gchar *str,
  * @bytes_read:    location to store the number of bytes in the
  *                 input string that were successfully converted, or %NULL.
  *                 Even if the conversion was succesful, this may be 
- *                 less than len if there were partial characters
+ *                 less than @len if there were partial characters
  *                 at the end of the input. If the error
- *                 G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
- *                 stored will the byte fofset after the last valid
+ *                 #G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
+ *                 stored will the byte offset after the last valid
  *                 input sequence.
- * @bytes_written: the stored in the output buffer (not including the
- *                 terminating nul.
+ * @bytes_written: the number of bytes stored in the output buffer (not 
+ *                 including the terminating NULL).
  * @error:         location to store the error occuring, or %NULL to ignore
  *                 errors. Any of the errors in #GConvertError may occur.
  *
  * Convert a string from one character set to another.
  *
  * Return value: If the conversion was successful, a newly allocated
- *               NUL-terminated string, which must be freed with
- *               g_free. Otherwise %NULL and @error will be set.
+ *               nul-terminated string, which must be freed with
+ *               g_free(). Otherwise %NULL and @error will be set.
  **/
 gchar*
 g_convert_with_iconv (const gchar *str,
@@ -349,10 +408,10 @@ g_convert_with_iconv (const gchar *str,
  * @bytes_read:   location to store the number of bytes in the
  *                input string that were successfully converted, or %NULL.
  *                Even if the conversion was succesful, this may be 
- *                less than len if there were partial characters
+ *                less than @len if there were partial characters
  *                at the end of the input.
- * @bytes_written: the stored in the output buffer (not including the
- *                 terminating nul.
+ * @bytes_written: the number of bytes stored in the output buffer (not 
+ *                including the terminating NULL).
  * @error:        location to store the error occuring, or %NULL to ignore
  *                errors. Any of the errors in #GConvertError may occur.
  *
@@ -365,8 +424,8 @@ g_convert_with_iconv (const gchar *str,
  * will simply return that approximate conversion.
  *
  * Return value: If the conversion was successful, a newly allocated
- *               NUL-terminated string, which must be freed with
- *               g_free. Otherwise %NULL and @error will be set.
+ *               nul-terminated string, which must be freed with
+ *               g_free(). Otherwise %NULL and @error will be set.
  **/
 gchar*
 g_convert_with_fallback (const gchar *str,
@@ -603,18 +662,18 @@ strdup_len (const gchar *string,
  * g_locale_to_utf8:
  * @opsysstring:   a string in the encoding of the current locale
  * @len:           the length of the string, or -1 if the string is
- *                 NULL-terminated.
+ *                 nul-terminated.
  * @bytes_read:    location to store the number of bytes in the
  *                 input string that were successfully converted, or %NULL.
  *                 Even if the conversion was succesful, this may be 
- *                 less than len if there were partial characters
+ *                 less than @len if there were partial characters
  *                 at the end of the input. If the error
- *                 G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
- *                 stored will the byte fofset after the last valid
+ *                 #G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
+ *                 stored will the byte offset after the last valid
  *                 input sequence.
- * @bytes_written: the stored in the output buffer (not including the
- *                 terminating nul.
- * @error: location to store the error occuring, or %NULL to ignore
+ * @bytes_written: the number of bytes stored in the output buffer (not 
+ *                 including the terminating NULL).
+ * @error:         location to store the error occuring, or %NULL to ignore
  *                 errors. Any of the errors in #GConvertError may occur.
  * 
  * Converts a string which is in the encoding used for strings by
@@ -743,18 +802,18 @@ g_locale_to_utf8 (const gchar  *opsysstring,
  * g_locale_from_utf8:
  * @utf8string:    a UTF-8 encoded string 
  * @len:           the length of the string, or -1 if the string is
- *                 NULL-terminated.
+ *                 nul-terminated.
  * @bytes_read:    location to store the number of bytes in the
  *                 input string that were successfully converted, or %NULL.
  *                 Even if the conversion was succesful, this may be 
- *                 less than len if there were partial characters
+ *                 less than @len if there were partial characters
  *                 at the end of the input. If the error
- *                 G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
- *                 stored will the byte fofset after the last valid
+ *                 #G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
+ *                 stored will the byte offset after the last valid
  *                 input sequence.
- * @bytes_written: the stored in the output buffer (not including the
- *                 terminating nul.
- * @error: location to store the error occuring, or %NULL to ignore
+ * @bytes_written: the number of bytes stored in the output buffer (not 
+ *                 including the terminating NULL).
+ * @error:         location to store the error occuring, or %NULL to ignore
  *                 errors. Any of the errors in #GConvertError may occur.
  * 
  * Converts a string from UTF-8 to the encoding used for strings by
@@ -889,18 +948,18 @@ g_locale_from_utf8 (const gchar *utf8string,
  * g_filename_to_utf8:
  * @opsysstring:   a string in the encoding for filenames
  * @len:           the length of the string, or -1 if the string is
- *                 NULL-terminated.
+ *                 nul-terminated.
  * @bytes_read:    location to store the number of bytes in the
  *                 input string that were successfully converted, or %NULL.
  *                 Even if the conversion was succesful, this may be 
- *                 less than len if there were partial characters
+ *                 less than @len if there were partial characters
  *                 at the end of the input. If the error
- *                 G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
- *                 stored will the byte fofset after the last valid
+ *                 #G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
+ *                 stored will the byte offset after the last valid
  *                 input sequence.
- * @bytes_written: the stored in the output buffer (not including the
- *                 terminating nul.
- * @error: location to store the error occuring, or %NULL to ignore
+ * @bytes_written: the number of bytes stored in the output buffer (not 
+ *                 including the terminating NULL).
+ * @error:         location to store the error occuring, or %NULL to ignore
  *                 errors. Any of the errors in #GConvertError may occur.
  * 
  * Converts a string which is in the encoding used for filenames
@@ -932,20 +991,20 @@ g_filename_to_utf8 (const gchar *opsysstring,
 
 /**
  * g_filename_from_utf8:
- * @utf8string:    a UTF-8 encoded string 
+ * @utf8string:    a UTF-8 encoded string.
  * @len:           the length of the string, or -1 if the string is
- *                 NULL-terminated.
+ *                 nul-terminated.
  * @bytes_read:    location to store the number of bytes in the
  *                 input string that were successfully converted, or %NULL.
  *                 Even if the conversion was succesful, this may be 
- *                 less than len if there were partial characters
+ *                 less than @len if there were partial characters
  *                 at the end of the input. If the error
- *                 G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
- *                 stored will the byte fofset after the last valid
+ *                 #G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value
+ *                 stored will the byte offset after the last valid
  *                 input sequence.
- * @bytes_written: the stored in the output buffer (not including the
- *                 terminating nul.
- * @error: location to store the error occuring, or %NULL to ignore
+ * @bytes_written: the number of bytes stored in the output buffer (not 
+ *                 including the terminating NULL).
+ * @error:         location to store the error occuring, or %NULL to ignore
  *                 errors. Any of the errors in #GConvertError may occur.
  * 
  * Converts a string from UTF-8 to the encoding used for filenames.
@@ -1168,7 +1227,7 @@ g_unescape_uri_string (const gchar *escaped,
 
 /**
  * g_filename_from_uri:
- * @uri: a uri describing a filename (escaped, encoded in UTF-8)
+ * @uri: a uri describing a filename (escaped, encoded in UTF-8).
  * @hostname: Location to store hostname for the URI, or %NULL.
  *            If there is no hostname in the URI, %NULL will be
  *            stored in this location.
@@ -1198,8 +1257,8 @@ g_filename_from_uri (const char *uri,
 
   if (!has_case_prefix (uri, "file:/"))
     {
-      g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_NOT_ABSOLUTE_FILE_URI,
-		   _("The URI `%s' is not an absolute URI using the file scheme"),
+      g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_BAD_URI,
+		   _("The URI '%s' is not an absolute URI using the file scheme"),
 		   uri);
       return NULL;
     }
@@ -1208,8 +1267,8 @@ g_filename_from_uri (const char *uri,
   
   if (strchr (path_part, '#') != NULL)
     {
-      g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_INVALID_URI,
-		   _("The local file URI `%s' may not include a `#'"),
+      g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_BAD_URI,
+		   _("The local file URI '%s' may not include a '#'"),
 		   uri);
       return NULL;
     }
@@ -1225,8 +1284,8 @@ g_filename_from_uri (const char *uri,
 
       if (path_part == NULL)
 	{
-	  g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_INVALID_URI,
-		       _("The URI `%s' is invalid"),
+	  g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_BAD_URI,
+		       _("The URI '%s' is invalid"),
 		       uri);
 	  return NULL;
 	}
@@ -1234,8 +1293,8 @@ g_filename_from_uri (const char *uri,
       unescaped_hostname = g_unescape_uri_string (host_part, "", path_part - host_part);
       if (unescaped_hostname == NULL)
 	{
-	  g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_INVALID_URI,
-		       _("The hostname of the URI `%s' is contains invalidly escaped characters"),
+	  g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_BAD_URI,
+		       _("The hostname of the URI '%s' contains invalidly escaped characters"),
 		       uri);
 	  return NULL;
 	}
@@ -1250,8 +1309,8 @@ g_filename_from_uri (const char *uri,
 
   if (filename == NULL)
     {
-      g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_INVALID_URI,
-		   _("The URI `%s' is contains invalidly escaped characters"),
+      g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_BAD_URI,
+		   _("The URI '%s' contains invalidly escaped characters"),
 		   uri);
       return NULL;
     }
