@@ -671,3 +671,42 @@ g_cclosure_marshal_VOID__UINT_POINTER (GClosure     *closure,
             data2);
 }
 
+/* BOOL:FLAGS (./gmarshal.list:47) */
+void
+g_cclosure_marshal_BOOLEAN__FLAGS (GClosure     *closure,
+                                   GValue       *return_value,
+                                   guint         n_param_values,
+                                   const GValue *param_values,
+                                   gpointer      invocation_hint,
+                                   gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__FLAGS) (gpointer     data1,
+                                                   guint        arg_1,
+                                                   gpointer     data2);
+  register GMarshalFunc_BOOLEAN__FLAGS callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__FLAGS) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_value_get_flags (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
