@@ -18,16 +18,19 @@
  *
  * gvalue.h: generic GValue functions
  */
+#if !defined (__GLIB_GOBJECT_H_INSIDE__) && !defined (GOBJECT_COMPILATION)
+#error "Only <glib-object.h> can be included directly."
+#endif
+
 #ifndef __G_VALUE_H__
 #define __G_VALUE_H__
 
-
 #include	<gobject/gtype.h>
 
 G_BEGIN_DECLS
 
 /* --- type macros --- */
-#define	G_TYPE_IS_VALUE(type)		(g_type_value_table_peek (type) != NULL)
+#define	G_TYPE_IS_VALUE(type)		(g_type_check_is_value_type (type))
 #define	G_IS_VALUE(value)		(G_TYPE_CHECK_VALUE (value))
 #define	G_VALUE_TYPE(value)		(((GValue*) (value))->g_type)
 #define	G_VALUE_TYPE_NAME(value)	(g_type_name (G_VALUE_TYPE (value)))
